@@ -26,7 +26,7 @@ class Experimento:
 
     def __init__(self, nombre_archivo, dimension_caja=[100, 100], cantidad_filas=10, cantidad_columnas=10,
                  procesar_tiempo_archivo_irregular=False, puntos_importantes=None, objeto_a_promediar=1,
-                 tamanio_intervalo_para_promedio=100, genera_matriz_recurrencia=False, regiones_preferidas=None,
+                 tamanio_intervalo_para_promedio=100, genera_matriz_recurrencia=False, arreglo_regiones_preferidas=None,
                  genera_regiones_preferidas=True, distancia_max_para_volumenes=24, division_de_dist_max=2):
         self.nombre_archivo = nombre_archivo
         print("NOMBRE_ARCHIVO:", self.nombre_archivo, "\n TIPO_ARCHIVO:", type(self.nombre_archivo))
@@ -114,7 +114,7 @@ class Experimento:
             self.objeto_relevante_3 = puntos_importantes[2]
             self.objeto_relevante_4 = puntos_importantes[3]
 
-        self.regiones_preferidas = regiones_preferidas
+        self.regiones_preferidas = arreglo_regiones_preferidas
         total_regiones = list(range(0, cantidad_columnas*cantidad_filas))
         self.regiones_no_preferidas = rp.obtener_complemento_de_sublista(lista=total_regiones,
                                                                          sublista=self.regiones_preferidas)
